@@ -116,6 +116,20 @@ class StellarClass(object):
        The height of the bounding box in pixels.  If set to
        :const:`None`, the value recommended by the sprite is used.
 
+    .. attribute:: regulate_origin
+
+       If set to :const:`True`, the origin is automatically adjusted to
+       be the location of the pixel recommended by the sprite after
+       transformation.  This will cause rotation to be about the origin
+       rather than being about the center of the image.
+
+       .. note::
+
+          The value of this attribute has no effect on the bounding box.
+          If you wish for the bounding box to be adjusted as well, you
+          must do so manually.  As an alternative, you may want to
+          consider using precise collision detection instead.
+
     .. attribute:: collision_ellipse
 
        Whether or not an ellipse (rather than a rectangle) should be
@@ -170,6 +184,18 @@ class StellarClass(object):
        The animation frame currently being displayed, with ``0`` being
        the first one.
 
+    .. attribute:: image_origin_x
+
+       The horizontal location of the origin relative to the left edge
+       of the images.  If set to :const:`None`, the value recommended by
+       the sprite is used.
+
+    .. attribute:: image_origin_y
+
+       The vertical location of the origin relative to the top edge of
+       the images.  If set to :const:`None`, the value recommended by
+       the sprite is used.
+
     .. attribute:: image_fps
 
        The animation rate in frames per second.  If set to
@@ -193,6 +219,10 @@ class StellarClass(object):
        The rotation of the sprite in degrees, with rotation in a
        positive direction being counter-clockwise.
 
+       If :attr:`regulate_origin` is :const:`True`, the image is rotated
+       about the origin.  Otherwise, the image is rotated about its
+       center.
+
     .. attribute:: image_alpha
 
        The alpha value applied to the entire image, where ``255`` is the
@@ -208,6 +238,12 @@ class StellarClass(object):
 
        The unique identifier for this object.  (Read-only)
 
+    .. attribute:: mask
+
+       The current mask used for non-rectangular collision detection.
+       See the documentation for :func:`sge.collision.masks_collide` for
+       more information.  (Read-only)
+
     .. attribute:: xstart
 
        The initial value of :attr:`x` when the object was created.
@@ -228,15 +264,24 @@ class StellarClass(object):
        The value of :attr:`y` at the end of the previous frame.
        (Read-only)
 
+    .. attribute:: mask_x
+
+       The horizontal location of the mask in the room.  (Read-only)
+
+    .. attribute:: mask_y
+
+       The vertical location of the mask in the room.  (Read-only)
+
     """
 
     def __init__(self, x, y, z=0, ID=None, sprite=None, visible=True,
                  active=True, detects_collisions=True, bbox_x=None,
                  bbox_y=None, bbox_width=None, bbox_height=None,
-                 collision_ellipse=False, collision_precise=False,
-                 xvelocity=0, yvelocity=0, image_index=0, image_fps=None,
-                 image_xscale=1, image_yscale=1, image_rotation=0,
-                 image_alpha=255, image_blend=None):
+                 regulate_origin=False, collision_ellipse=False,
+                 collision_precise=False, xvelocity=0, yvelocity=0,
+                 image_index=0, image_origin_x=None, image_origin_y=None,
+                 image_fps=None, image_xscale=1, image_yscale=1,
+                 image_rotation=0, image_alpha=255, image_blend=None):
         """Constructor method.
 
         Arguments:
@@ -253,14 +298,21 @@ class StellarClass(object):
         """
         # TODO
 
-    def collides(self, other, x=None, y=None):
-        """Return whether or not this object collides with another.
+    def collision(self, other=None, x=None, y=None):
+        """Return a list of objects colliding with this object.
 
         Arguments:
 
-        - ``other`` -- The object to check for a collision with, or the
-          unique identifier of said object.  ``other`` can also be a
-          class to check for collisions with.
+        - ``other`` -- What to check for collisions with.  Can be one of
+          the following:
+
+          - A :class:`sge.StellarClass` object.
+          - The unique identifier of a :class:`sge.StellarClass` object.
+          - A list of :class:`sge.StellarClass` objects and/or unique
+            identifiers of :class:`sge.StellarClass` objects.
+          - A class derived from :class:`sge.StellarClass`.
+          - :const:`None`: Check for collisions with all objects.
+
         - ``x`` -- The horizontal position to pretend this object is at
           for the purpose of the collision detection.  If set to
           :const:`None`, :attr:`x` will be used.
@@ -318,7 +370,7 @@ class StellarClass(object):
         """Destroy event."""
         pass
 
-    def event_begin_step(self, time_passed):
+    def event_begin_step(self, time_passed, delta_mult):
         """Begin step event.
 
         This event is executed each frame before automatic updates to
@@ -337,7 +389,20 @@ class StellarClass(object):
         """
         pass
 
-    def event_step(self, time_passed):
+    def event_step(self, time_passed, delta_mult):
+        """Step event.
+
+        This event is executed each frame after automatic updates to
+        objects (such as the effects of the speed variables), but before
+        collision events.
+
+        See the documentation for :meth:`sge.Game.event_step` for more
+        information.
+
+        """
+        pass
+
+    def event_end_step(self, time_passed, delta_mult):
         """Step event.
 
         This event is executed each frame after automatic updates to
@@ -465,6 +530,26 @@ class StellarClass(object):
         """
         pass
 
+    def event_update_position(self, delta_mult):
+        """Update position event.
+
+        Called when it's time to update the position of the object.
+        This method handles this functionality, so defining this will
+        override the default behavior and allow you to handle the speed
+        variables in a special way.
+
+        The default behavior of this method is::
+
+            self.x += self.xvelocity * delta_mult
+            self.y += self.yvelocity * delta_mult
+
+        See the documentation for :meth:`sge.Game.event_step` for more
+        information.
+
+        """
+        self.x += self.xvelocity * delta_mult
+        self.y += self.yvelocity * delta_mult
+
     def event_collision(self, other):
         """Default collision event.
 
@@ -544,6 +629,7 @@ class StellarClass(object):
         """
         self.event_collision(other)
 
+    def event_inactive_step(self, time_passed, delta_mult):
         """Step event when this object is inactive.
 
         See the documentation for :meth:`sge.StellarClass.event_step`
@@ -553,7 +639,7 @@ class StellarClass(object):
         """
         pass
 
-    def event_inactive_end_step(self, time_passed):
+    def event_inactive_end_step(self, time_passed, delta_mult):
         """End step event when this object is inactive.
 
         See the documentation for
